[PATCH 3 of 5] copies: expand `_chain` variable name to make the function easier to read

Pierre-Yves David pierre-yves.david at ens-lyon.org
Mon Dec 2 06:28:18 EST 2019


# HG changeset patch
# User Pierre-Yves David <pierre-yves.david at octobus.net>
# Date 1573674128 -3600
#      Wed Nov 13 20:42:08 2019 +0100
# Node ID aecdfe3c798f29670f341d88c7a4b7e2289500e9
# Parent  2671000fb23f978fbacb56cd168d4a5f529c0b59
# EXP-Topic patch-copies-rust-prep
# Available At https://dev.heptapod.net/octobus/mercurial-devel/
#              hg pull https://dev.heptapod.net/octobus/mercurial-devel/ -r aecdfe3c798f
copies: expand `_chain` variable name to make the function easier to read

This came up while explaining what the function is about. I find the function
easier to follow that way.

diff --git a/mercurial/copies.py b/mercurial/copies.py
--- a/mercurial/copies.py
+++ b/mercurial/copies.py
@@ -63,12 +63,12 @@ def _filter(src, dst, t):
             del t[k]
 
 
-def _chain(a, b):
-    """chain two sets of copies 'a' and 'b'"""
-    t = a.copy()
-    for k, v in pycompat.iteritems(b):
-        t[k] = a.get(v, v)
-    return t
+def _chain(prefix, suffix):
+    """chain two sets of copies 'prefix' and 'suffix'"""
+    result = prefix.copy()
+    for key, value in pycompat.iteritems(suffix):
+        result[key] = prefix.get(value, value)
+    return result
 
 
 def _tracefile(fctx, am, basemf):


More information about the Mercurial-devel mailing list